@@ -204,7 +204,7 @@ sudo cpm install -gvv $pkg
 
 # AUTHOR
 
-$author [$email](mailto:$email)
+$author <$email>
 
 # LICENSE
 
@@ -224,7 +224,7 @@ __END__
 
 =head1 NAME
 
-Liveman::Append - adds sections for methods and functions from C<lib/**.pm> to C<lib/**.md>
+Liveman :: Append - adds sections for methods and functions from C<Lib/**. Pm> toC<Lib/**. Md>
 
 =head1 SYNOPSIS
 
@@ -236,13 +236,13 @@ Liveman::Append - adds sections for methods and functions from C<lib/**.pm> to C
 
 =head1 DESCRIPTION
 
-Adds a manual about module methods and functions (C<lib/**.pm>) to their manuals (C<lib/**.md>).
+Adds a guide on the methods and functions of the modules (C<Lib/**. PM>) to their guidelines (C<Lib/**. MD>).
 
 =over
 
-=item 1. Methods is a Perl subroutine starting with the C<sub> keyword.
+=item 1. Methods are a Perl subprogram starting with the keyword C<sub>.
 
-=item 2. Features are instance properties added by OOP frameworks such as C<Aion>, C<Moose>, C<Moo>, C<Mo>, and starting with the C<has> keyword.
+=item 2. Features are the properties of copies added by OOP-frames, such as C<Aion>,C<Moose>, C<Moo>,C<Mo>, and starting with the keyword C<HAS>.
 
 =back
 
@@ -254,15 +254,15 @@ Constructor.
 
 =head2 mkmd ($md)
 
-Creates an md file.
+Creates an MD file.
 
 =head2 appends ()
 
-Adds routines and features to C<lib/**.md> from C<lib/**.pm>.
+Adds to C<Lib/**. Md> fromC<Lib/**. Pm> subprograms and features.
 
 =head2 append ($path)
 
-Adds routines and functions from a module (C<$path>) to its manual.
+Adds subprograms and functions from the module (C<$ Path>) to its manual.
 
 File lib/Alt/The/Plan.pm:
 
@@ -353,7 +353,7 @@ File lib/Alt/The/Plan.md is:
 	
 	# AUTHOR
 	
-	Yaroslav O. Kosmina [dart@cpan.org](mailto:dart@cpan.org)
+	Yaroslav O. Kosmina <dart@cpan.org>
 	
 	# LICENSE
 	
@@ -369,8 +369,8 @@ Yaroslav O. Kosmina L<mailto:dart@cpan.org>
 
 =head1 LICENSE
 
-⚖ B<GPLv3>
+⚖ I<* gplv3 *>
 
 =head1 COPYRIGHT
 
-The Liveman::Append module is copyright © 2023 Yaroslav O. Kosmina. Rusland. All rights reserved.
+The Liveman :: Append Module is Copyright © 2023 Yaroslav O. Kosmina. Rusland. All Rights Reserved.
